unit DataModule;

interface

uses
  SysUtils, Windows, Classes, Graphics, Controls,
  Forms, Dialogs, DB, DBTables;

const
  Seperator = ',';

type
  TDataModule1 = class(TDataModule)
    Table1Nr: TIntegerField;
    Table1Naam: TStringField;
    Table1Voornaam: TStringField;
    Table1Adres: TStringField;
    Table1Postcode: TStringField;
    Table1Plaats: TStringField;
    Table1Gebruiker: TStringField;
    Table1Tijdstempel: TDateTimeField;
    DataSource1: TDataSource;
    Table1: TTable;
    procedure DataModuleCreate(Sender: TObject);
  private
    { private declarations }
    function SeperatorCount(CSVLine: string): Integer;
    function CSVGetField(CSVLine: String; Field: Integer): string;
  public
    { public declarations }
    procedure ImportCSV(FileName: string);
  end;

var
  DataModule1: TDataModule1;

implementation


{$R *.DFM}

function TDataModule1.SeperatorCount(CSVLine: string): Integer;
var
  i      ,
  Count  : Integer;
begin
  Count := 0;
  { Count all comma's present in the line }
  for i := 1 to Length(CSVLine) do
  begin
    if CSVLine[i] = Seperator then Inc(Count);
  end;
  { Return counted fields }
  Result := Count;
end;

function TDataModule1.CSVGetField(CSVLine: String; Field: Integer): string;
var
  Parts  : array of string;
  i      : Integer;
begin
  { Adjust array size to cope with the fields }
  SetLength(Parts, SeperatorCount(CSVLine));
  { Parse the line into seperate parts }
  for i := 0 to Pred(SeperatorCount(CSVLine)) do
  begin
    Parts[i] := Copy(CSVLine, 1, Pred(Pos(Seperator, CSVLine)));
    Delete(CSVLine, 1, Pos(Seperator, CSVLine));
  end;
  Result := Parts[Field];
end;

procedure TDataModule1.ImportCSV(FileName: string);
var
  Headers : array of string;
  F         : TextFile;
  TempStr   : string;
  i         : Integer;
begin
  { Open the file }
  AssignFile(F, FileName);
  Reset(F);
  { Read the headers }
  ReadLn(F, TempStr);
  { Add a ending ; this makes the parser simpler }
  TempStr := TempStr + Seperator;
  { Adjust Headers/Fields size to copy with the data }
  SetLength(Headers, SeperatorCount(TempStr));

  { Seperate the fields }
  for i := 0 to Pred(SeperatorCount(TempStr)) do
  begin
    Headers[i] := CSVGetField(TempStr, i);
  end;

  { repeat the loop until the file ends }
  while not EOF(F) do
  begin
    ReadLn(F, TempStr);
    { Add a ending ; this makes the parser simpler }
    TempStr := TempStr + Seperator;

    { Put the database into insert mode }
    Table1.Insert;

    { Seperate the fields }
    for i := 0 to Pred(SeperatorCount(TempStr)) do
    begin
      Table1.FieldByName(Headers[i]).AsString := CSVGetField(TempStr, i);
    end;

    { Commit the changes we just made to the database }
    Table1.Post;
  end;
  { Close the file }
  CloseFile(F);
end;

procedure TDataModule1.DataModuleCreate(Sender: TObject);
begin
  Table1.Open;
end;

end.
